@@ -45,6 +45,7 @@ from cleanlab_tlm.internal.types import JSONDict
 
 if TYPE_CHECKING:
     import requests
+    from openai.types.chat import ChatCompletion
 
     from cleanlab_tlm.internal.concurrency import TlmRateHandler
     from cleanlab_tlm.utils.rag import Eval
@@ -53,6 +54,7 @@ if TYPE_CHECKING:
 base_url = os.environ.get("CLEANLAB_API_BASE_URL", "https://api.cleanlab.ai/api")
 tlm_base_url = f"{base_url}/v0/trustworthy_llm"
 tlm_rag_base_url = f"{base_url}/v1/rag_trustworthy_llm"
+tlm_openai_base_url = f"{base_url}/v1/openai_trustworthy_llm"
 
 
 def _construct_headers(api_key: Optional[str], content_type: Optional[str] = "application/json") -> JSONDict:
@@ -115,7 +117,7 @@ def handle_rate_limit_error_from_resp(resp: aiohttp.ClientResponse) -> None:
         )
 
 
-async def handle_tlm_client_error_from_resp(resp: aiohttp.ClientResponse, batch_index: Optional[int]) -> None:
+async def handle_tlm_client_error_from_resp(resp: aiohttp.ClientResponse, batch_index: Optional[int] = None) -> None:
     """Catches 4XX (client error) errors."""
     if 400 <= resp.status < 500:  # noqa: PLR2004
         try:
@@ -133,7 +135,7 @@ async def handle_tlm_client_error_from_resp(resp: aiohttp.ClientResponse, batch_
         raise TlmBadRequestError(error_message, retryable)
 
 
-async def handle_tlm_api_error_from_resp(resp: aiohttp.ClientResponse, batch_index: Optional[int]) -> None:
+async def handle_tlm_api_error_from_resp(resp: aiohttp.ClientResponse, batch_index: Optional[int] = None) -> None:
     """Catches 5XX (server error) errors."""
     if 500 <= resp.status < 600:  # noqa: PLR2004
         try:
@@ -527,3 +529,51 @@ async def tlm_rag_score(
             ordered_res[evaluation.name] = res_json[evaluation.name]
 
     return ordered_res
+
+
+@tlm_retry
+async def tlm_chat_completions_score(
+    api_key: str,
+    response: ChatCompletion,
+    client_session: Optional[aiohttp.ClientSession] = None,
+    **input_kwargs: Any,
+) -> JSONDict:
+    """
+    Score an OpenAI ChatCompletion response using Trustworthy Language Model
+
+    Args:
+        api_key (str): API key for auth
+        response (ChatCompletion): response to be evaluated (OpenAI ChatCompletion object)
+        client_session (aiohttp.ClientSession): client session used to issue TLM request
+        **input_kwargs: additional keyword arguments (openai arguments or TLM options) to pass to the TLM request.
+    Returns:
+        JSONDict: dictionary with trustworthiness score and any evaluation results
+    """
+    local_scoped_client = False
+    if not client_session:
+        client_session = aiohttp.ClientSession()
+        local_scoped_client = True
+
+    try:
+        res = await client_session.post(
+            f"{tlm_openai_base_url}/score",
+            json={
+                "response": response.model_dump(),
+                **input_kwargs,
+            },
+            headers=_construct_headers(api_key),
+        )
+
+        res_json = await res.json()
+
+        await handle_api_key_error_from_resp(res)
+        await handle_http_bad_request_error_from_resp(res)
+        handle_rate_limit_error_from_resp(res)
+        await handle_tlm_client_error_from_resp(res)
+        await handle_tlm_api_error_from_resp(res)
+
+    finally:
+        if local_scoped_client:
+            await client_session.close()
+
+    return cast(JSONDict, res_json)
