@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 import os
 import warnings
 from collections.abc import Sequence
-from typing import Any, Callable, Optional, Union
+from typing import TYPE_CHECKING, Any, Callable, Optional, Union
 
 from cleanlab_tlm.errors import ValidationError
 from cleanlab_tlm.internal.constants import (
@@ -10,7 +12,6 @@ from cleanlab_tlm.internal.constants import (
     _TLM_MAX_TOKEN_RANGE,
     _VALID_TLM_MODELS,
     INVALID_SCORE_OPTIONS,
-    TLM_MODELS_NOT_SUPPORTING_EXPLANATION,
     TLM_NUM_CANDIDATE_RESPONSES_RANGE,
     TLM_NUM_CONSISTENCY_SAMPLES_RANGE,
     TLM_NUM_SELF_REFLECTIONS_RANGE,
@@ -24,6 +25,10 @@ from cleanlab_tlm.internal.constants import (
 )
 from cleanlab_tlm.internal.types import Task
 
+if TYPE_CHECKING:
+    from cleanlab_tlm.tlm import TLMOptions
+    from cleanlab_tlm.utils.rag import Eval
+
 SKIP_VALIDATE_TLM_OPTIONS: bool = os.environ.get("CLEANLAB_TLM_SKIP_VALIDATE_TLM_OPTIONS", "false").lower() == "true"
 
 
@@ -161,8 +166,6 @@ def validate_tlm_options(
             invalid_log_options = set(val) - TLM_VALID_LOG_OPTIONS
 
             model = options.get("model", _TLM_DEFAULT_MODEL)
-            if "explanation" in val and model in TLM_MODELS_NOT_SUPPORTING_EXPLANATION:
-                raise ValidationError(f"Explanation is not supported for this model: {model}. ")
 
             if invalid_log_options:
                 raise ValidationError(
@@ -198,6 +201,27 @@ def validate_tlm_options(
 
                 if not isinstance(criteria.get("criteria"), str):
                     raise ValidationError(f"'criteria' in custom_eval_criteria item {i} must be a string.")
+        elif option == "disable_trustworthiness":
+            if not isinstance(val, bool):
+                raise ValidationError(f"Invalid type {type(val)}, disable_trustworthiness must be a boolean")
+            if val and support_custom_eval_criteria and not options.get("custom_eval_criteria"):
+                raise ValidationError("disable_trustworthiness is only supported when custom_eval_criteria is provided")
+
+
+def _validate_trustworthy_rag_options(options: Optional[TLMOptions], initialized_evals: list[Eval]) -> None:
+    """To be used for ensuring TLMOptions are set correctly given other parameters to TrustworthyRAG
+
+    options: TLMOptions
+    initialized_evals: list[Eval]
+        The evals field configured in TrustworthyRAG.__init__. Required to validate disable_trustworthiness option.
+    """
+    disable_trustworthiness = options and options.get("disable_trustworthiness", False)
+
+    if disable_trustworthiness and not initialized_evals:
+        raise ValidationError(
+            "When disable_trustworthiness=True in TrustworthyRAG, at least one evaluation must be provided. "
+            "Either provide evaluations via the 'evals' parameter or set disable_trustworthiness=False."
+        )
 
 
 def process_and_validate_kwargs_constrain_outputs(
