@@ -201,6 +201,13 @@ def test_init_with_quality_preset(trustworthy_rag_api_key: str, quality_preset:
     assert tlm_rag._quality_preset == quality_preset
 
 
+def test_get_model_name(trustworthy_rag: TrustworthyRAG) -> None:
+    model_name = trustworthy_rag.get_model_name()
+
+    assert model_name == trustworthy_rag._options["model"]
+    assert model_name == _TLM_DEFAULT_MODEL
+
+
 def test_get_evals(trustworthy_rag: TrustworthyRAG) -> None:
     evals = trustworthy_rag.get_evals()
 
@@ -955,3 +962,30 @@ def reset_rag_timeout(trustworthy_rag: TrustworthyRAG) -> Generator[None, None,
     old_timeout = trustworthy_rag._timeout
     yield
     trustworthy_rag._timeout = old_timeout
+
+
+def test_score_with_disable_trustworthiness(trustworthy_rag_api_key: str) -> None:
+    """Tests score with disable_trustworthiness option.
+
+    When disable_trustworthiness is enabled (along with valid evals),
+    the trustworthiness score should be None in the response.
+
+    Expected:
+    - TrustworthyRAG should return a response
+    - response should have the trustworthiness key
+    - trustworthiness score should be None
+    - No exceptions are raised
+    """
+    trustworthy_rag = TrustworthyRAG(
+        api_key=trustworthy_rag_api_key,
+        options={"disable_trustworthiness": True},
+    )
+    response = trustworthy_rag.score(
+        query=test_query,
+        context=test_context,
+        response=test_response,
+        prompt=test_prompt,
+    )
+    assert not isinstance(response, list)
+    assert "trustworthiness" in response
+    assert response["trustworthiness"]["score"] is None
