@@ -687,6 +687,22 @@ def test_validate_tlm_options_support_custom_eval_criteria() -> None:
     ):
         validate_tlm_options(options, support_custom_eval_criteria=False)
 
+    # Valid with disable_trustworthiness=True and custom_eval_criteria
+    validate_tlm_options({**options, "disable_trustworthiness": True}, support_custom_eval_criteria=True)
+
+    # Invalid: disable_trustworthiness=True without custom_eval_criteria
+    with pytest.raises(
+        ValidationError, match="^disable_trustworthiness is only supported when custom_eval_criteria is provided"
+    ):
+        validate_tlm_options({"disable_trustworthiness": True}, support_custom_eval_criteria=True)
+
+    with pytest.raises(
+        ValidationError, match="^disable_trustworthiness is only supported when custom_eval_criteria is provided"
+    ):
+        validate_tlm_options(
+            {"disable_trustworthiness": True, "custom_eval_criteria": None}, support_custom_eval_criteria=True
+        )
+
 
 def test_validate_rag_inputs_mixed_string_and_sequence() -> None:
     """Tests that validate_rag_inputs rejects mixed inputs where some are strings and others are sequences."""
@@ -798,3 +814,37 @@ def test_validate_rag_inputs_matching_lists() -> None:
     assert len(result) == list_length
     assert result[0] == "Q: query 1 C: context 1"
     assert result[1] == "Q: query 2 C: context 2"
+
+
+def test_disable_trustworthiness_without_custom_criteria_raises_error(tlm_api_key: str) -> None:
+    """Test that disable_trustworthiness=True without custom_eval_criteria raises ValueError."""
+    with pytest.raises(
+        ValidationError, match="^disable_trustworthiness is only supported when custom_eval_criteria is provided"
+    ):
+        TLM(api_key=tlm_api_key, options={"disable_trustworthiness": True})
+
+
+def test_disable_trustworthiness_with_custom_criteria_works(tlm_api_key: str) -> None:
+    """Test that disable_trustworthiness=True with custom_eval_criteria works normally."""
+    TLM(
+        api_key=tlm_api_key,
+        options={
+            "disable_trustworthiness": True,
+            "custom_eval_criteria": [{"name": "test", "criteria": "test criteria"}],
+        },
+    )
+
+
+def test_disable_trustworthiness_without_custom_criteria_raises_error_rag(tlm_api_key: str) -> None:
+    """Test that disable_trustworthiness=True without custom_eval_criteria raises ValueError for TrustworthyRAG."""
+    from cleanlab_tlm.utils.rag import TrustworthyRAG
+
+    with pytest.raises(ValidationError, match="^When disable_trustworthiness=True in TrustworthyRAG"):
+        TrustworthyRAG(evals=[], api_key=tlm_api_key, options={"disable_trustworthiness": True})
+
+
+def test_disable_trustworthiness_with_custom_criteria_works_rag(tlm_api_key: str) -> None:
+    """Test that disable_trustworthiness=True with custom_eval_criteria works normally for TrustworthyRAG."""
+    from cleanlab_tlm.utils.rag import TrustworthyRAG
+
+    TrustworthyRAG(api_key=tlm_api_key, options={"disable_trustworthiness": True})
